@@ -1,8 +1,6 @@
-use stop_words;
-
 fn main() {
     // Get the stop words
-    let x = stop_words::get_iso("en");
+    let x = stop_words::get("en");
     let y = stop_words::get(stop_words::LANGUAGE::English);
 
     // Print them
